<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>CAboutWindow</name>
    <message>
        <location filename="../rvln.cpp" line="4771"/>
        <source>Code</source>
        <translation>Код</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="4772"/>
        <source>Acknowledgements</source>
        <translation>Благодарности</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="4773"/>
        <source>Translations</source>
        <translation>Переводы</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="4774"/>
        <source>Packages</source>
        <translation>Пакеты</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="4782"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
</context>
<context>
    <name>CDarkerWindow</name>
    <message>
        <location filename="../rvln.cpp" line="8442"/>
        <source>Darker palette</source>
        <translation>Палитра темнее</translation>
    </message>
</context>
<context>
    <name>CDocument</name>
    <message>
        <location filename="../document.cpp" line="128"/>
        <source>cannot open %1 because of: %2</source>
        <translation>Не могу открыть %1, ибо %2</translation>
    </message>
    <message>
        <location filename="../document.cpp" line="181"/>
        <source>cannot save %1 because of: %2</source>
        <translation>не могу сохранить %1, ибо %2</translation>
    </message>
    <message>
        <location filename="../document.cpp" line="192"/>
        <source>%1 is saved</source>
        <translation>%1 сохранён</translation>
    </message>
    <message>
        <location filename="../document.cpp" line="257"/>
        <source>%1 has been modified.
Do you want to save your changes?</source>
        <translation>%1 был изменен. Желаете сохранить изменения?</translation>
    </message>
    <message>
        <location filename="../document.cpp" line="147"/>
        <source>%1 is open</source>
        <translation>%1 открыт</translation>
    </message>
    <message>
        <location filename="../document.cpp" line="207"/>
        <source>new[%1]</source>
        <translation>новый[%1]</translation>
    </message>
</context>
<context>
    <name>CFontBox</name>
    <message>
        <location filename="../fontbox.cpp" line="32"/>
        <source>Example string</source>
        <translation>Строка примера</translation>
    </message>
    <message>
        <location filename="../fontbox.cpp" line="37"/>
        <source>Font gallery</source>
        <translation>Галерея шрифтов</translation>
    </message>
</context>
<context>
    <name>CImgViewer</name>
    <message>
        <location filename="../img_viewer.cpp" line="27"/>
        <source>preview</source>
        <translation>просмотр</translation>
    </message>
</context>
<context>
    <name>CTioReadOnly</name>
    <message>
        <location filename="../tio.cpp" line="145"/>
        <source>saving of this format is not supported</source>
        <translation>сохранение этого формата не поддерживается</translation>
    </message>
</context>
<context>
    <name>CTodo</name>
    <message>
        <location filename="../todo.cpp" line="39"/>
        <source>Attention! Attention!</source>
        <translation>Внимание! Внимание!</translation>
    </message>
</context>
<context>
    <name>CViewerWindow</name>
    <message>
        <source>preview</source>
        <translation type="obsolete">просмотр</translation>
    </message>
</context>
<context>
    <name>CZORWindow</name>
    <message>
        <source> scaled to</source>
        <translation type="obsolete">масштабировано к </translation>
    </message>
    <message>
        <location filename="../img_viewer.cpp" line="410"/>
        <source>scaled to: </source>
        <translation>масштабировано к:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../fman.cpp" line="257"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../fman.cpp" line="258"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../fman.cpp" line="259"/>
        <source>Modified at</source>
        <translation>Изменено</translation>
    </message>
</context>
<context>
    <name>QuaZipFile</name>
    <message>
        <location filename="../quazipfile.cpp" line="180"/>
        <source>ZIP/UNZIP API error %1</source>
        <translation>ZIP/UNZIP ошибка API %1</translation>
    </message>
</context>
<context>
    <name>rvln</name>
    <message>
        <location filename="../rvln.cpp" line="1174"/>
        <source>Create a new file</source>
        <translation>Создать новый файл</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1183"/>
        <source>Open an existing file</source>
        <translation>Открыть существующий файл</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1191"/>
        <source>Save the document to disk</source>
        <translation>Сохранить документ на диск</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1195"/>
        <source>Save the document under a new name</source>
        <translation>Сохранить документ под именем</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1200"/>
        <source>Exit the application</source>
        <translation>Выйти из программы</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1208"/>
        <source>Cut the current selection&apos;s contents to the clipboard</source>
        <translation>Вырезать текущее выделение в буфер обмена</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1217"/>
        <source>Copy the current selection&apos;s contents to the clipboard</source>
        <translation>Копировать текущее выделение в буфер обмена</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1226"/>
        <source>Paste the clipboard&apos;s contents into the current selection</source>
        <translation>Вставить из буфера обмена</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1254"/>
        <source>Open at cursor</source>
        <translation>Открыть под курсором</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1266"/>
        <source>Save .bak</source>
        <translation>Сохранить запасную копию</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1383"/>
        <source>Insert image</source>
        <translation>Вставить картинку</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1401"/>
        <source>Find</source>
        <translation>Найти</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1402"/>
        <source>Find next</source>
        <translation>Найти дальше</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1403"/>
        <source>Find previous</source>
        <translation>Найти назад</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1472"/>
        <source>Case</source>
        <translation>Регистр</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1246"/>
        <location filename="../rvln.cpp" line="1740"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1304"/>
        <location filename="../rvln.cpp" line="1746"/>
        <source>Edit</source>
        <translation>Правка</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1772"/>
        <source>Ready</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2399"/>
        <source>Editor font</source>
        <translation>Шрифт редактора</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2388"/>
        <source>UI style</source>
        <translation>Стиль интерфейса</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2482"/>
        <source>Word wrap</source>
        <translation>Перенос строк</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="968"/>
        <location filename="../rvln.cpp" line="1099"/>
        <location filename="../rvln.cpp" line="5630"/>
        <location filename="../rvln.cpp" line="6102"/>
        <source>Charset</source>
        <translation>Кодировка</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1160"/>
        <source>Test</source>
        <translation>Проверка</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1171"/>
        <source>New</source>
        <translation>Новый</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1252"/>
        <location filename="../rvln.cpp" line="5648"/>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1189"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="482"/>
        <source>FIF</source>
        <translation>ЗПВ</translation>
    </message>
    <message>
        <source>&lt;b&gt;TEA %1&lt;/b&gt; by Peter Semiletov - tea@list.ru&lt;br&gt;site 1: http://semiletov.org/tea&lt;br&gt;site 2: http://tea.ourproject.org&lt;br&gt;read the Manual under the &lt;i&gt;Learn&lt;/i&gt; tab!</source>
        <translation type="obsolete">&lt;b&gt;TEA %1&lt;/b&gt; от Петра Семилетова - tea@list.ru&lt;br&gt;сайт 1: http://semiletov.org/tea&lt;br&gt;сайт 2: http://tea.ourproject.org&lt;br&gt;читайте Руководство на вкладке &lt;i&gt;Узнать&lt;/i&gt;!</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1194"/>
        <source>Save As</source>
        <translation>Сохранить как</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1198"/>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1206"/>
        <source>Cut</source>
        <translation>Вырезать</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1215"/>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1224"/>
        <source>Paste</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1229"/>
        <source>Undo</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1233"/>
        <source>Redo</source>
        <translation>Переделать</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1236"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1239"/>
        <source>About Qt</source>
        <translation>О Qt</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1255"/>
        <source>Crapbook</source>
        <translation>Фигня</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1281"/>
        <source>Recent files</source>
        <translation>Последние файлы</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1298"/>
        <source>Print</source>
        <translation>Печатать</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1343"/>
        <source>Markup</source>
        <translation>Вёрстка</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1398"/>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1444"/>
        <location filename="../rvln.cpp" line="2880"/>
        <source>Functions</source>
        <translation>Функции</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1507"/>
        <source>Filter with regexp</source>
        <translation>Фильтровать по регэкспу</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1553"/>
        <source>Apply to each line</source>
        <translation>Применить к каждой строке</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1560"/>
        <source>Reverse</source>
        <translation>Перевернуть</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1475"/>
        <source>UPCASE</source>
        <translation>ВЕРХНИЙ</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1476"/>
        <source>lower case</source>
        <translation>нижний</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1582"/>
        <source>Add to dictionary</source>
        <translation>Добавить в словарь</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1581"/>
        <source>Suggest</source>
        <translation>Предположить</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1580"/>
        <source>Spell check</source>
        <translation>Проверить правописание</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1577"/>
        <source>Spell-checker languages</source>
        <translation>Языки проверки правописания</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1625"/>
        <source>Nav</source>
        <translation>Нав</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1628"/>
        <source>Save position</source>
        <translation>Запомнить место</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1629"/>
        <source>Go to saved position</source>
        <translation>К сохранённому месту</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1630"/>
        <source>Go to line</source>
        <translation>К строке</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1695"/>
        <source>View</source>
        <translation>Вид</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1722"/>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2955"/>
        <source>Assign</source>
        <translation>Назначить</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2956"/>
        <source>Remove</source>
        <translation>Удалить привязку</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2970"/>
        <source>Keyboard</source>
        <translation>Клавиатура</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="494"/>
        <source>edit</source>
        <translation>править</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1263"/>
        <source>Save as different</source>
        <translation>Сохранить иначе</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1267"/>
        <source>Save timestamped version</source>
        <translation>Сохранить версию по времени</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1289"/>
        <source>Templates</source>
        <translation>Шаблоны</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1283"/>
        <source>Bookmarks</source>
        <translation>Закладки</translation>
    </message>
    <message>
        <source>&lt;b&gt;TEA %1 @ http://tea-editor.sourceforge.net&lt;/b&gt;&lt;br&gt;by Peter Semiletov (peter.semiletov@gmail.com)&lt;br&gt;read the Manual under the &lt;i&gt;Learn&lt;/i&gt; tab!</source>
        <translation type="obsolete">&lt;b&gt;TEA %1 @ http://tea-editor.sourceforge.net&lt;/b&gt;&lt;br&gt;разработка Петра Семилетова (peter.semiletov@gmail.com)&lt;br&gt;читайте руководство на вкладке &lt;i&gt;Узнать&lt;/i&gt;!</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="966"/>
        <source>All (*);;Text files (*.txt);;Markup files (*.xml *.html *.htm *.);;C/C++ (*.c *.h *.cpp *.hh *.c++ *.h++ *.cxx)</source>
        <translation>Все (*);;Текстовые файлы (*.txt);;Файлы разметки (*.xml *.html *.htm *.);;C/C++ (*.c *.h *.cpp *.hh *.c++ *.h++ *.cxx)</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1168"/>
        <location filename="../rvln.cpp" line="1637"/>
        <location filename="../rvln.cpp" line="2763"/>
        <source>Labels</source>
        <translation>Метки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1256"/>
        <source>Notes</source>
        <translation>Заметки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1276"/>
        <source>Set UNIX end of line</source>
        <translation>Установить конец строки как в UNIX</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1277"/>
        <source>Set Windows end of line</source>
        <translation>Установить конец строки как в Windows</translation>
    </message>
    <message>
        <source>Set traditional Mac end of line</source>
        <translation type="obsolete">Установить конец строки как в Mac</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1285"/>
        <source>Edit bookmarks</source>
        <translation>Править закладки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1286"/>
        <source>Add to bookmarks</source>
        <translation>Добавить в закладки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1287"/>
        <source>Find obsolete paths</source>
        <translation>Найти ошибочные пути</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1299"/>
        <source>Close current</source>
        <translation>Закрыть текущий файл</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1317"/>
        <source>Copy current file name</source>
        <translation>Копировать имя текущего файла</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1328"/>
        <source>Indent by first line</source>
        <translation>Отступ по первой строке</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1332"/>
        <source>Comment selection</source>
        <translation>Закомментировать выделенное</translation>
    </message>
    <message>
        <source>Variants</source>
        <translation type="obsolete">Варианты</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1337"/>
        <source>Set as storage file</source>
        <translation>Установить как файл хранилища</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1338"/>
        <source>Copy to storage file</source>
        <translation>Копировать в файл хранилища</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1339"/>
        <source>Start/stop capture clipboard to storage file</source>
        <translation>Захватить/нет буфер обмена в файл хранилища</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1346"/>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1353"/>
        <source>Header</source>
        <translation>Заголовок</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1360"/>
        <source>Align</source>
        <translation>Выравнивание</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1368"/>
        <source>Center</source>
        <translation>Середина</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1371"/>
        <source>Justify</source>
        <translation>По ширине</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1385"/>
        <source>[X]HTML tools</source>
        <translation>Инструменты [X]HTML</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1388"/>
        <source>Text to [X]HTML</source>
        <translation>Из текста в [X]HTML</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1389"/>
        <source>Convert tags to entities</source>
        <translation>Перевести тэги в сущности</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1390"/>
        <source>Antispam e-mail</source>
        <translation>Кодировать адрес e-mail супротив спама</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1391"/>
        <source>Document weight</source>
        <translation>Взвесить документ</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1393"/>
        <source>Strip HTML tags</source>
        <translation>Очистить от HTML-тэгов</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1394"/>
        <source>Rename selected file</source>
        <translation>Переименовать выделенный файл</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1407"/>
        <source>Find in files</source>
        <translation>Найти в файлах</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1411"/>
        <source>Replace with</source>
        <translation>Заменить на</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1412"/>
        <source>Replace all</source>
        <translation>Заменить всё</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1413"/>
        <source>Replace all in opened files</source>
        <translation>Заменить всё в открытых файлах</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1427"/>
        <source>From cursor</source>
        <translation>От курсора</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1433"/>
        <source>Regexp mode</source>
        <translation>В режиме регулярных выражений</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1439"/>
        <source>Fuzzy mode</source>
        <translation>Нечеткое условие</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1449"/>
        <source>Plugins</source>
        <translation>Плагины</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1453"/>
        <source>Snippets</source>
        <translation>Сниппеты</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1455"/>
        <source>Tables</source>
        <translation>Таблицы</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1462"/>
        <source>HTML5 template</source>
        <translation>Шаблон HTML5</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1464"/>
        <source>C++ template</source>
        <translation>Шаблон C++</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1465"/>
        <source>C template</source>
        <translation>Шаблон C</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1468"/>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1469"/>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1479"/>
        <source>Sort</source>
        <translation>Сортировка</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1482"/>
        <source>Sort case sensitively</source>
        <translation>Сортировать учитывая регистр</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1484"/>
        <source>Flip a list</source>
        <translation>Перевернуть список</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1487"/>
        <source>Cells</source>
        <translation>Ячейки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1490"/>
        <source>Sort table by column ABC</source>
        <translation>Упорядочить таблицу по столбцу в алфавитном порядке</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1491"/>
        <source>Swap cells</source>
        <translation>Поменять местами ячейки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1492"/>
        <source>Delete by column</source>
        <translation>Удалить по столбцу</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1493"/>
        <source>Copy by column[s]</source>
        <translation>Копировать по столбцу(цам)</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1497"/>
        <source>Filter</source>
        <translation>Фильтр</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1500"/>
        <source>Remove duplicates</source>
        <translation>Удалить повторения</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1501"/>
        <source>Remove empty lines</source>
        <translation>Удалить пустые строки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1502"/>
        <source>Remove lines &lt; N size</source>
        <translation>Удалить строки &lt; размера N</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1503"/>
        <source>Remove lines &gt; N size</source>
        <translation>Удалить строки &gt; размера N</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1504"/>
        <source>Remove before delimiter at each line</source>
        <translation>Удалить перед разделителем в каждой строке</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1505"/>
        <source>Remove after delimiter at each line</source>
        <translation>Удалить после разделителя в каждой строке</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1517"/>
        <source>Decimal to binary</source>
        <translation>Десятичное в двоичное</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1518"/>
        <source>Binary to decimal</source>
        <translation>Двоичное в десятичное</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1519"/>
        <source>Flip bits (bitwise complement)</source>
        <translation>Перевернуть биты</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1521"/>
        <source>Sum by last column</source>
        <translation>Сложить по последнему столбцу</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1526"/>
        <source>Morse code</source>
        <translation>Азбука Морзе</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1529"/>
        <source>From Russian to Morse</source>
        <translation>Из русского в морзянку</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1530"/>
        <source>From Morse To Russian</source>
        <translation>Из морзянки в русский</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1532"/>
        <source>From English to Morse</source>
        <translation>С английского в код Морзе</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1533"/>
        <source>From Morse To English</source>
        <translation>Из кода Морзе на английский</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1539"/>
        <source>Text statistics</source>
        <translation>Статистика по тексту</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1540"/>
        <source>Extract words</source>
        <translation>Извлечь слова</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1541"/>
        <source>Words lengths</source>
        <translation>Длины слов</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1555"/>
        <source>Remove formatting at each line</source>
        <translation>Удалить форматирование в каждой строке</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1700"/>
        <source>Themes</source>
        <translation>Темы</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2106"/>
        <source>not found!</source>
        <translation>не найдено!</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2468"/>
        <source>TEA program icon</source>
        <translation>Иконка программы</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2554"/>
        <source>Use Alt key to access main menu</source>
        <translation>Использовать клавишу Alt для доступа к главному меню</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5784"/>
        <source>It seems that %1 contains TEA plugin.
 Do you want to install it?</source>
        <translation>Кажется, что %1 содержит плагин для TEA. Установить его?</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="8526"/>
        <source>put your notes (for this file) here and they will be saved automatically</source>
        <translation>пишите свои заметки (к этому файлу) здесь, и они будут автоматически сохранены</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="9378"/>
        <source>sum: %1</source>
        <translation>сумма: %1</translation>
    </message>
    <message>
        <source>put your notes here and they will be saved automatically</source>
        <translation type="obsolete">пишите свои заметки к файлу здесь, и они будут автоматически сохранены</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="8647"/>
        <location filename="../rvln.cpp" line="8764"/>
        <source>There is no plugin file</source>
        <translation>Нет файла плагина</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="8776"/>
        <source>&lt;b&gt;Error:&lt;/b&gt; </source>
        <translation>&lt;b&gt;Ошибка:&lt;/b&gt; </translation>
    </message>
    <message>
        <source>variants</source>
        <translation type="obsolete">варианты</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="8496"/>
        <source>Word length: </source>
        <translation>Длина слова:</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="8497"/>
        <source>Number:</source>
        <translation>Количество:</translation>
    </message>
    <message>
        <source>variants file %1 is not exist</source>
        <translation type="obsolete">файл вариантов %1 не существует</translation>
    </message>
    <message>
        <source>put your notes here</source>
        <translation type="obsolete">здесь мож</translation>
    </message>
    <message>
        <source>Double quotes to TeX double quotes</source>
        <translation type="obsolete">Двойные кавычки в TeX двойные кавычки</translation>
    </message>
    <message>
        <source>Double quotes to TeX Russian quotes &lt;&lt; &gt;&gt;</source>
        <translation type="obsolete">Двойные кавычки в TeX русские кавычки &lt;&lt; &gt;&gt;</translation>
    </message>
    <message>
        <source>Double quotes to TeX Russian quotes</source>
        <translation type="obsolete">Двойные кавычки в TeX русские кавычки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1593"/>
        <source>Moon mode on/off</source>
        <translation>Лунный режим вкл/выкл</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1594"/>
        <source>Mark first date</source>
        <translation>Пометить первую дату</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1595"/>
        <source>Mark last date</source>
        <translation>Пометить последнюю дату</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1609"/>
        <source>Go to current date</source>
        <translation>Перейти к текущей дате</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1610"/>
        <source>Calculate moon days between dates</source>
        <translation>Вычислить лунные дни между датами</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1611"/>
        <source>Number of days between two dates</source>
        <translation>Количество дней между двумя датами</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1616"/>
        <source>Instr</source>
        <translation>Инстр</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1619"/>
        <source>Font gallery</source>
        <translation>Галерея шрифтов</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1638"/>
        <source>Refresh labels</source>
        <translation>Обновить метки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1640"/>
        <source>Current files</source>
        <translation>Текущие файлы</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1672"/>
        <source>List ZIP content</source>
        <translation>Показать содержимое ZIP</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1673"/>
        <source>Unpack ZIP to current directory</source>
        <translation>Распаковать ZIP в текущий каталог</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2430"/>
        <source>Add user font</source>
        <translation>Добавить пользовательский шрифт</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2567"/>
        <source>Old syntax hl engine (restart TEA to apply)</source>
        <translation>Старый движок подсветки синтаксиса (нужен перезапуск TEA)</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2590"/>
        <source>Use external image viewer for F2</source>
        <translation>Использовать внешнюю смотрелку картинок для F2</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2626"/>
        <source>Northern hemisphere</source>
        <translation>Северное полушарие</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2631"/>
        <source>Moon phase algorithm</source>
        <translation>Алгоритм фазы луны</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2644"/>
        <source>UI tabs align</source>
        <translation>Положение вкладок интерфейса</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2648"/>
        <source>Up</source>
        <translation>Вверху</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1370"/>
        <location filename="../rvln.cpp" line="2651"/>
        <source>Right</source>
        <translation>Справа</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2866"/>
        <source>Fuzzy search factor</source>
        <translation>Коэффициент поиска по нечеткому условию</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="3341"/>
        <source>snippet %1 is not exists</source>
        <translation>сниппет %1 не существует</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="7034"/>
        <location filename="../rvln.cpp" line="7059"/>
        <source>Open Directory</source>
        <translation>Открыть каталог</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="8077"/>
        <source> is unpacked</source>
        <translation>распакованы</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="8217"/>
        <source>Trigonometric 2</source>
        <translation>Тригонометрический 2</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="8218"/>
        <source>Trigonometric 1</source>
        <translation>Тригонометрический 1</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="8219"/>
        <source>Conway</source>
        <translation>Конуэй</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="8221"/>
        <source>Leueshkanov</source>
        <translation>Леушканов</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1369"/>
        <location filename="../rvln.cpp" line="2650"/>
        <source>Left</source>
        <translation>Слева</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2671"/>
        <source>Documents tabs align</source>
        <translation>Положение вкладок документов</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2649"/>
        <source>Bottom</source>
        <translation>Снизу</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2703"/>
        <source>ZIP unpacking: file names charset</source>
        <translation>ZIP-распаковка: кодировка имен файлов</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2715"/>
        <source>ZIP packing: file names charset</source>
        <translation>ZIP-упаковка: кодировка имен файлов</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2767"/>
        <source>Label starts with: </source>
        <translation>Метка начинается с:</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2768"/>
        <source>Label ends with: </source>
        <translation>Метка завершается:</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2948"/>
        <source>Shortcut</source>
        <translation>Сочетание клавиш</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="4008"/>
        <location filename="../rvln.cpp" line="6973"/>
        <source>%1 is processed and saved</source>
        <translation>%1 обработан и сохранен</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="7842"/>
        <source>Select the file name first!</source>
        <translation>Выделите сначала имя файла!</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="7932"/>
        <source>Select font</source>
        <translation>Выберите шрифт</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="7933"/>
        <source>Fonts (*.ttf *.otf)</source>
        <translation>Шрифты (*.ttf *.otf)</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1590"/>
        <source>Calendar</source>
        <translation>Календарь</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="780"/>
        <source>&lt;b&gt;TEA %1&lt;/b&gt; by Peter Semiletov, tea@list.ru&lt;br&gt;site 1: http://semiletov.org/tea&lt;br&gt;site 2: http://tea.ourproject.org&lt;br&gt;site 3 (development): https://github.com/psemiletov/tea-qt&lt;br&gt;read the Manual under the &lt;i&gt;Learn&lt;/i&gt; tab!</source>
        <translation>&lt;b&gt;TEA %1&lt;/b&gt; Петр Семилетов, tea@list.ru&lt;br&gt;site 1: http://semiletov.org/tea&lt;br&gt;site 2: http://tea.ourproject.org&lt;br&gt;site 3 (разработка): https://github.com/psemiletov/tea-qt&lt;br&gt;читайте руководство на вкладке &lt;i&gt;Узнать&lt;/i&gt;!</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1568"/>
        <source>LaTeX: Straight to curly double quotes</source>
        <translation>LaTeX: прямые двойные в нижние и верхние</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1569"/>
        <source>LaTeX: Straight to double angle quotes</source>
        <translation>LaTeX: прямые двойные в елочкой вар.1</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1570"/>
        <source>LaTeX: Straight to double angle quotes v2</source>
        <translation>LaTeX: прямые двойные в елочкой вар.2</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1598"/>
        <source>Add or subtract</source>
        <translation>Добавить или вычесть</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1601"/>
        <source>Days</source>
        <translation>Дни</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1602"/>
        <source>Months</source>
        <translation>Месяцы</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1603"/>
        <source>Years</source>
        <translation>Годы</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1613"/>
        <source>Remove day record</source>
        <translation>Удалить данные о дне</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2622"/>
        <source>Start week on Sunday</source>
        <translation>Неделя начинается в воскресенье</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2862"/>
        <location filename="../rvln.cpp" line="2889"/>
        <source>Miscellaneous</source>
        <translation>Разное</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="6020"/>
        <source>End of line: </source>
        <translation>Конец строки: </translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="7297"/>
        <source>Getting files list...</source>
        <translation>Получение списка файлов...</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="7303"/>
        <source>Searching...</source>
        <translation>Ищу...</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="7326"/>
        <source>cannot open %1 because of: %2</source>
        <translation>Не могу открыть %1, ибо %2</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="7342"/>
        <source>Search results</source>
        <translation>Итоги поиска</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1164"/>
        <location filename="../rvln.cpp" line="1756"/>
        <location filename="../rvln.cpp" line="7342"/>
        <source>Files</source>
        <translation>Файлы</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="7388"/>
        <source>new_profile</source>
        <translation>новый профиль</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="7477"/>
        <source>There are %1 lines at %2 files</source>
        <translation>%1 строк в %2 файлах</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="7603"/>
        <source>Enter your daily notes here.
To use time-based reminders, specify the time signature in 24-hour format [hh:mm], i.e.:
[06:00]good morning!
[20:10]go to theatre</source>
        <translation>Введите тут свои заметки.
Чтобы включить напоминалку, используйте временные пометки в 24-часовом формате [чч:мм], то есть:
[06:00]доброе утро!
[20:10]выйти за хлебом, когда всё закрыто</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="7611"/>
        <source>Enter your daily notes here.</source>
        <translation>Можете вписать тут свои заметки.</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1514"/>
        <source>Evaluate</source>
        <translation>Вычислить</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1631"/>
        <source>Next tab</source>
        <translation>Следующая вкладка</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1632"/>
        <source>Prev tab</source>
        <translation>Предыдущая вкладка</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1633"/>
        <source>Toggle header/source</source>
        <translation>Переключить заголовок/исходник</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1635"/>
        <source>Focus the editor</source>
        <translation>Фокус в редактор</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2416"/>
        <source>Interface font</source>
        <translation>Шрифт интерфейса</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2454"/>
        <source>Icons size</source>
        <translation>Размер иконок</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2780"/>
        <source>Date format</source>
        <translation>Формат даты</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2781"/>
        <source>Time format</source>
        <translation>Формат времени</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="3313"/>
        <source>learn</source>
        <translation>узнать</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="7646"/>
        <source>dates</source>
        <translation>даты</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="8027"/>
        <source>%1 kbytes %2 &lt;br&gt;</source>
        <translation>%1 килобайт %2 &lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="8032"/>
        <source>Total size = %1 kbytes in %2 files&lt;br&gt;</source>
        <translation>Общий вес = %1 килобайт в %2 файлах&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1121"/>
        <location filename="../rvln.cpp" line="4877"/>
        <source>%1 already exists
Do you want to overwrite?</source>
        <translation>%1 уже существует
Желаете перезаписать?</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1511"/>
        <source>Math</source>
        <translation>Математика</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1515"/>
        <source>Arabic to Roman</source>
        <translation>Арабское в римское</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2517"/>
        <source>Show cursor position</source>
        <translation>Отображать положение курсора</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="3735"/>
        <source>%1 - saved</source>
        <translation>%1 - сохранён</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="3737"/>
        <source>Cannot save %1</source>
        <translation>Не могу сохранить %1</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1292"/>
        <source>Configs</source>
        <translation>Конфиги</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1293"/>
        <source>Bookmarks list</source>
        <translation>Список закладок</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1294"/>
        <source>Programs list</source>
        <translation>Список программ</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1461"/>
        <source>HTML template</source>
        <translation>Шаблон HTML</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1623"/>
        <source>Run</source>
        <translation>Запуск</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2306"/>
        <source>%1 is saved</source>
        <translation>%1 был сохранен </translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1457"/>
        <source>Place</source>
        <translation>Поместить</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1373"/>
        <source>Bold</source>
        <translation>Жирный</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1374"/>
        <source>Italic</source>
        <translation>Наклонный</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1377"/>
        <source>Link</source>
        <translation>Ссылка</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1378"/>
        <source>Paragraph</source>
        <translation>Параграф</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1379"/>
        <source>Color</source>
        <translation>Цвет</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1381"/>
        <source>Break line</source>
        <translation>Перенос строки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1382"/>
        <source>Non-breaking space</source>
        <translation>Неразрывный пробел</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1516"/>
        <source>Roman to Arabic</source>
        <translation>Римское в арабское</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1550"/>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1554"/>
        <source>Remove formatting</source>
        <translation>Удалить форматирование</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="4528"/>
        <source>#external programs list. example:
opera=opera %s</source>
        <translation>#список внешних программ. пример:
opera=opera %s</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="8013"/>
        <source>%1 is not found&lt;br&gt;</source>
        <translation>%1 не найден&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1715"/>
        <source>Toggle word wrap</source>
        <translation>Переключить перенос строк</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1716"/>
        <source>Hide error marks</source>
        <translation>Скрыть помеченное как ошибки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1717"/>
        <source>Toggle fullscreen</source>
        <translation>Переключить полноэкранный режим</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1720"/>
        <source>Preview with default browser</source>
        <translation>Просмотр в браузере по умолчанию</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1730"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1454"/>
        <source>Scripts</source>
        <translation>Скрипты</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1727"/>
        <source>NEWS</source>
        <translation>Новости</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5600"/>
        <source>Home</source>
        <translation>Домой</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5603"/>
        <source>Refresh</source>
        <translation>Освежить</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5651"/>
        <source>Save as</source>
        <translation>Сохранить как</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2619"/>
        <source>Use traditional File Save/Open dialogs</source>
        <translation>Использовать традиционные окна Открыть/Сохранить</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="4990"/>
        <source>templates</source>
        <translation>шаблоны</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="4991"/>
        <source>snippets</source>
        <translation>сниппеты</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="4992"/>
        <source>scripts</source>
        <translation>скрипты</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5923"/>
        <source>Are you sure to delete
%1?</source>
        <translation>Вы уверены, что хотите удалить
%1?</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5586"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5597"/>
        <source>Go</source>
        <translation>Перейти</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1649"/>
        <source>Create new directory</source>
        <translation>Создать новый каталог</translation>
    </message>
    <message>
        <source>Quotes to facing quotes</source>
        <translation type="obsolete">Кавычки в кавычки ёлочкой</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2578"/>
        <source>Override locale</source>
        <translation>Перекрыть локаль</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1268"/>
        <source>Save session</source>
        <translation>Сохранить сессию</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1290"/>
        <source>Sessions</source>
        <translation>Сессии</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1520"/>
        <source>Enumerate</source>
        <translation>Нумеровать</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1718"/>
        <source>Stay on top</source>
        <translation>Поверх других окон</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2575"/>
        <source>Restore the last session on start-up</source>
        <translation>Загружать последнюю сессию при запуске</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2757"/>
        <source>Common</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="3895"/>
        <source>chars: %1&lt;br&gt;chars without spaces: %2&lt;br&gt;lines: %3&lt;br&gt;author&apos;s sheets: %4</source>
        <translation>символов: %1&lt;br&gt;символов без пробелов: %2&lt;br&gt;строк: %3&lt;br&gt;авторских листов: %4</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1253"/>
        <source>Last closed file</source>
        <translation>Последний закрытый файл</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1392"/>
        <source>Preview selected color</source>
        <translation>Смотреть выделенный цвет</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1704"/>
        <source>Palettes</source>
        <translation>Палитры</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2497"/>
        <source>Highlight current line</source>
        <translation>Подсвечивать текущую строку</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2502"/>
        <source>Highlight paired brackets</source>
        <translation>Подсвечивать парные скобки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5567"/>
        <source>&lt;span style=&quot;%1&quot;&gt;COLOR SAMPLE&lt;/span&gt;</source>
        <translation>&lt;span style=&quot;%1&quot;&gt;ОБРАЗЕЦ ЦВЕТА&lt;/span&gt;</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1643"/>
        <source>Fm</source>
        <translation>Фп</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1583"/>
        <source>Remove from dictionary</source>
        <translation>Удалить из словаря</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1646"/>
        <source>File operations</source>
        <translation>Действия над файлами</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1650"/>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1651"/>
        <source>Delete file</source>
        <translation>Удалить файл</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1653"/>
        <source>File information</source>
        <translation>Сведения о файле</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1660"/>
        <source>MD5 checksum</source>
        <translation>Проверочная сумма MD5</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1661"/>
        <source>MD4 checksum</source>
        <translation>Проверочная сумма MD4</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1662"/>
        <source>SHA1 checksum</source>
        <translation>Проверочная сумма SHA1</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1681"/>
        <source>Create web gallery</source>
        <translation>Создать веб-галерею</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1684"/>
        <source>Go to home dir</source>
        <translation>В домашний каталог</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1685"/>
        <source>Refresh current dir</source>
        <translation>Обновить текущий каталог</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2531"/>
        <source>Show margin at</source>
        <translation>Показывать границу на</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1676"/>
        <location filename="../rvln.cpp" line="2928"/>
        <source>Images</source>
        <translation>Картинки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1657"/>
        <source>Count lines in selected files</source>
        <translation>Подсчитать строки в выбранных файлах</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1689"/>
        <source>Select by regexp</source>
        <translation>Отметить по регэкспу</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1690"/>
        <source>Deselect by regexp</source>
        <translation>Снять выделение по регэкспу</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1710"/>
        <source>Profiles</source>
        <translation>Профили</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1713"/>
        <source>Save profile</source>
        <translation>Сохранить профиль</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2477"/>
        <source>Show line numbers</source>
        <translation>Показывать номера строк</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2915"/>
        <source>Web gallery options</source>
        <translation>Настройки веб-галереи</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2918"/>
        <source>Size of the side</source>
        <translation>Размер стороны</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2919"/>
        <source>Link options</source>
        <translation>Настройки ссылки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2920"/>
        <source>Columns per row</source>
        <translation>Столбцов в ряду</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2775"/>
        <source>Date and time</source>
        <translation>Дата и время</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2790"/>
        <source>Spell checking</source>
        <translation>Проверка правописания</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2797"/>
        <source>Spell checker engine</source>
        <translation>Движок проверки правописания</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2807"/>
        <source>Hunspell dictionaries directory</source>
        <translation>Каталог со словарями для Hunspell</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2813"/>
        <location filename="../rvln.cpp" line="2838"/>
        <source>Select</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="3403"/>
        <source>Print document</source>
        <translation>Печатать документ</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="3536"/>
        <source>elapsed milliseconds: %1</source>
        <translation>прошло миллисекунд: %1</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5062"/>
        <location filename="../rvln.cpp" line="5232"/>
        <location filename="../rvln.cpp" line="5892"/>
        <location filename="../rvln.cpp" line="7386"/>
        <source>Enter the name</source>
        <translation>Введите имя</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5063"/>
        <location filename="../rvln.cpp" line="5233"/>
        <location filename="../rvln.cpp" line="5893"/>
        <location filename="../rvln.cpp" line="6781"/>
        <location filename="../rvln.cpp" line="7387"/>
        <source>Name:</source>
        <translation>Имя:</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5064"/>
        <source>new_directory</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5604"/>
        <source>Operations</source>
        <translation>Действия</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5894"/>
        <source>new</source>
        <translation>новый</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1658"/>
        <source>Full info</source>
        <translation>Полные сведения</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="4523"/>
        <source>#external programs list. example:
opera=&quot;C:\Program Files\Opera\opera.exe &quot; &quot;%s&quot;</source>
        <translation>#список внешних программ. вот пример:
opera=&quot;C:\Program Files\Opera\opera.exe &quot; &quot;%s&quot;</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="6039"/>
        <source>file name: %1</source>
        <translation>имя файла: %1</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="6040"/>
        <source>size: %1 kbytes</source>
        <translation>размер: %1 kbytes</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="6041"/>
        <source>created: %1</source>
        <translation>создан: %1</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="6042"/>
        <source>modified: %1</source>
        <translation>изменен: %1</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1272"/>
        <source>File actions</source>
        <translation>Действия над файлом</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1273"/>
        <source>Reload</source>
        <translation>Перечитать</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1274"/>
        <location filename="../rvln.cpp" line="6102"/>
        <source>Reload with encoding</source>
        <translation>Перечитать в кодировке</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="3320"/>
        <source>you can put here notes, etc</source>
        <translation>вы можете заносить сюда всякие заметки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1536"/>
        <source>Analyze</source>
        <translation>Анализ</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="6214"/>
        <source>total / unique: %1</source>
        <translation>всего / уникальных: %1</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="6215"/>
        <source>words unique: %1</source>
        <translation>слов, не считая повторы: %1</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="6216"/>
        <source>words total: %1</source>
        <translation>слов всего: %1</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="6217"/>
        <source>text analysis of: %1</source>
        <translation>анализ текста для: %1</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="6218"/>
        <source>UNITAZ: UNIverlsal Text AnalyZer</source>
        <translation>УНИТАЗ: УНИверсальный Текстовый АналиЗатор</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1422"/>
        <source>Whole words</source>
        <translation>Целые слова</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1418"/>
        <source>Case sensitive</source>
        <translation>Чуткость к регистру</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1543"/>
        <source>UNITAZ quantity sorting</source>
        <translation>УНИТАЗ с сортировкой по количеству</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1544"/>
        <source>UNITAZ sorting alphabet</source>
        <translation>УНИТАЗ с сортировкой по алфавиту</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2373"/>
        <source>tune</source>
        <translation>ладить</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="3458"/>
        <location filename="../rvln.cpp" line="6170"/>
        <location filename="../rvln.cpp" line="6673"/>
        <location filename="../rvln.cpp" line="7163"/>
        <location filename="../rvln.cpp" line="7308"/>
        <source>%p% completed</source>
        <translation>%p% выполнено</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5696"/>
        <source>&lt;b&gt;Bookmarks&lt;/b&gt;</source>
        <translation>&lt;b&gt;Закладки&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1634"/>
        <source>Focus the Famous input field</source>
        <translation>Фокус в Знаменитое поле ввода</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1180"/>
        <source>Open file</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1017"/>
        <source>This file is open in the read-only mode. You can save it with another name using &lt;b&gt;Save as&lt;/b&gt;</source>
        <translation>Файл открыт в режиме только для чтения. Можете сохранить его под другим именем через &lt;b&gt;Сохранить как&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1546"/>
        <source>Count the substring</source>
        <translation>Подсчитать вхождение подстроки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1547"/>
        <source>Count the substring (regexp)</source>
        <translation>Подсчитать вхождение подстроки (регэксп)</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5968"/>
        <source>MD4 checksum for %1 is %2</source>
        <translation>Проверочная сумма MD4 для %1 такова: %2</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5984"/>
        <source>SHA1 checksum for %1 is %2</source>
        <translation>Проверочная сумма SHA1 для %1 такова: %2</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="6213"/>
        <source>total to unique per cent diff: %1</source>
        <translation>всего к уникальным, проценты: %1</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="6527"/>
        <source>%1 number of occurrences of %2 is found</source>
        <translation>%1 вхождений %2 найдено</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5952"/>
        <source>MD5 checksum for %1 is %2</source>
        <translation>Проверочная сумма MD5 для %1 такова: %2</translation>
    </message>
    <message>
        <source>&lt;b&gt;TEA %1 @ http://semiletov.org/tea&lt;/b&gt;&lt;br&gt;by Peter Semiletov (e-mail: tea@list.ru, site: semiletov.org)&lt;br&gt;read the Manual under the &lt;i&gt;Learn&lt;/i&gt; tab!</source>
        <translation type="obsolete">&lt;b&gt;TEA %1 @ http://semiletov.org/tea&lt;/b&gt;&lt;br&gt;Петр Семилетов (мыло: tea@list.ru, сайт: semiletov.org)&lt;br&gt;читайте руководство на вкладе &lt;i&gt;Узнать&lt;/i&gt;!</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1278"/>
        <source>Set old Mac end of line (CR)</source>
        <translation>Установить старый Маковский конец строки (CR)</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1556"/>
        <source>Remove trailing spaces</source>
        <translation>Удалить хвостовые пробелы</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1558"/>
        <source>Escape regexp</source>
        <translation>Escape regexp</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1562"/>
        <source>Quotes</source>
        <translation>Кавычки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1565"/>
        <source>Straight to double angle quotes</source>
        <translation>Прямые двойные в елочкой</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1566"/>
        <source>Straight to curly double quotes</source>
        <translation>Прямые двойные в нижние и верхние</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1664"/>
        <source>ZIP</source>
        <translation>ZIP</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1667"/>
        <source>Create new ZIP</source>
        <translation>Создать новый ZIP</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1668"/>
        <source>Add to ZIP</source>
        <translation>Добавить в ZIP</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1669"/>
        <source>Save ZIP</source>
        <translation>Сохранить ZIP</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1679"/>
        <source>Scale by side</source>
        <translation>Масштабировать по стороне</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1680"/>
        <source>Scale by percentages</source>
        <translation>Масштабировать в процентах</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1719"/>
        <source>Darker</source>
        <translation>Темнее</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2527"/>
        <source>Cursor center on scroll</source>
        <translation>Курсор по центру при прокрутке</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2546"/>
        <source>Interface</source>
        <translation>Интерфейс</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2691"/>
        <source>Charset for file open from command line</source>
        <translation>Кодировка для открытия файла из командной строки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2832"/>
        <source>Aspell directory</source>
        <translation>Папка Aspell</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2895"/>
        <source>Image conversion output format</source>
        <translation>Выходной формат преобразованных картинок</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2899"/>
        <source>Scale images with bilinear filtering</source>
        <translation>Масштабировать картинки с билинейным фильтром</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2904"/>
        <source>Output images quality</source>
        <translation>Выходное качество картинок</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2907"/>
        <source>Zip directory with processed images</source>
        <translation>Упаковать каталог с преобразованными картинками</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="4993"/>
        <source>tables</source>
        <translation>таблицы</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5234"/>
        <source>new_session</source>
        <translation>новая сессия</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="5741"/>
        <source>manage</source>
        <translation>зырить</translation>
    </message>
    <message>
        <source>It seems that %1 contains TEA plugin
Do you want to install it?</source>
        <translation type="obsolete">Кажется, что %1 содержит плагин для TEA\nВы хотите установить его?</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="6780"/>
        <source>Enter the archive name</source>
        <translation>Введите имя архива</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="6782"/>
        <source>new_archive</source>
        <translation>new_archive</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1326"/>
        <source>Indent (tab)</source>
        <translation>Отступ (tab)</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1327"/>
        <source>Un-indent (shift+tab)</source>
        <translation>Отменить отступ (shift-tab)</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1687"/>
        <source>Preview image</source>
        <translation>Смотреть картинку</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2512"/>
        <source>Use spaces instead of tabs</source>
        <translation>Использовать пробелы вместо табов</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2507"/>
        <source>Automatic indent</source>
        <translation>Автоматический отступ</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2572"/>
        <source>Automatic preview images at file manager</source>
        <translation>Авто-показ картинок в файловом приказчике</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2524"/>
        <source>Tab width in spaces</source>
        <translation>Ширина таба в пробелах</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="2492"/>
        <source>Use wrap setting from highlighting module</source>
        <translation>Брать настройку переноса строк из модуля подсветки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1483"/>
        <source>Sort case insensitively</source>
        <translation>Сортировать без учёта регистра</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="6048"/>
        <source>bits per sample: %1</source>
        <translation>разрядность: %1</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="6049"/>
        <source>number of channels: %1</source>
        <translation>количество каналов: %1</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="6050"/>
        <source>sample rate: %1</source>
        <translation>частота оцифровки: %1</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="6052"/>
        <source>RMS for all channels: %1 dB</source>
        <translation>RMS для всех каналов: %1 dB</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1375"/>
        <source>Underline</source>
        <translation>Подчеркнутый</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="1707"/>
        <source>Highlighting mode</source>
        <translation>Режим подсветки</translation>
    </message>
    <message>
        <location filename="../rvln.cpp" line="4994"/>
        <source>configs</source>
        <translation>конфиги</translation>
    </message>
</context>
</TS>
